# Device service 
Микросервис отвечающий за работу с любыми устройствами взаимодействующими с системой.

![schema](doc/device_service.png)

Примерный функционал:
- Управление доступными прошивками
- Управление конфигурацией устройств
- Управление владением устройств
- Управление информацией об устройствах [тип, производитель, дата производства и т.д.]
- Управление маршрутизацией
- Обновление устройств
- Производственные журналы событий
- Управление таблицей соответствия устройств, прошивок и т.д.


## Глобальные зависимости
- ubuntu 20.04
- bash
- make
- python `3.8.10`
- pyenv
- pipenv
- docker-compose `1.27.4`
- docker `19.03.13`

